==> haskell-data-binary-ieee754-0.4.4-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-binary-ieee754
version:              0.4.4
visibility:           public
id:                   data-binary-ieee754-0.4.4-1uzt85nFoxu5Mgq2DE5oph
key:                  data-binary-ieee754-0.4.4-1uzt85nFoxu5Mgq2DE5oph
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/data-binary-ieee754/
synopsis:             Parser/Serialiser for IEEE-754 floating-point values
description:          Convert Float and Decimal values to/from raw octets.
category:             Data
abi:                  4c31e8ebbdcab3a2cf45a23a62f41e14
exposed:              True
exposed-modules:      Data.Binary.IEEE754
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-binary-ieee754-0.4.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-binary-ieee754-0.4.4
hs-libraries:         HSdata-binary-ieee754-0.4.4-1uzt85nFoxu5Mgq2DE5oph
depends:              base-4.15.0.0 binary-0.8.8.0
haddock-interfaces:
    /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock

haddock-html:         /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-binary-ieee754-0.4.4-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-binary-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-binary-ieee754
version:              0.4.4
visibility:           public
id:                   data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS
key:                  data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/data-binary-ieee754/
synopsis:             Parser/Serialiser for IEEE-754 floating-point values
description:          Convert Float and Decimal values to/from raw octets.
category:             Data
abi:                  427f8d03e1cf19daf24fe032183c1cac
exposed:              True
exposed-modules:      Data.Binary.IEEE754
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-binary-ieee754-0.4.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-binary-ieee754-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/data-binary-ieee754-0.4.4
hs-libraries:         HSdata-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS
depends:              base-4.15.1.0 binary-0.8.8.0
haddock-interfaces:
    /usr/share/doc/haskell-data-binary-ieee754/html/data-binary-ieee754.haddock

haddock-html:         /usr/share/doc/haskell-data-binary-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
